<?xml version="1.0" encoding="UTF-8" ?>

<!--
    Document   : users.xsl
    Created on : 07 March 2005, 15:32
    Author     : james
    Description: Stylesheet that displays user account administration
-->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fn="http://www.w3.org/2004/07/xpath-functions"
    xmlns:cfg="http://swiveltechnologies.com/xmlconfig" xmlns:usr="http://swiveltechnologies.com/users" xmlns:int="http://swiveltechnologies.com/interface"
    xmlns:hlp="http://swiveltechnologies.com/help" version="1.0">

    <!-- import menu stylesheet -->
    <xsl:import href="common.xsl" />
    <xsl:variable name="sectionName" select="''" />

    <!-- we're outputing html -->
    <xsl:output method="html" indent="yes" doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN" doctype-system="http://www.w3.org/TR/html4/loose.dtd" />

    <!-- parameters -->
    <xsl:param name="contextPath" />
    <xsl:param name="languageFile" />
    <xsl:param name="configFile" />
    <xsl:param name="interfaceFile" />
    <xsl:param name="helpFile" />
    <xsl:param name="cssClassFile" />
    <xsl:param name="page" />
    <xsl:param name="pages" />
    <xsl:param name="search" />
    <xsl:param name="filter" />
    <xsl:param name="admin" />
    <xsl:param name="helpDesk" />
    <xsl:param name="helpdeskView" />
    <xsl:param name="xmlHelpDesk" />
    <xsl:param name="repository" />
    <xsl:param name="servername" />
    <xsl:param name="maxUsers" />
    <xsl:param name="usersPerPage" />
    <xsl:param name="filterType" />
    <xsl:param name="userCount" />
    <xsl:param name="view" />
    <xsl:param name="userGroup" />
    <xsl:param name="noPassword" />
    <xsl:param name="editable" />
    <xsl:param name="userSet" />
    <xsl:param name="errorString" />
    <xsl:param name="noReset" />
    <xsl:param name="searchField" />
    <xsl:param name="canPurge"/>

    <!-- Creates the basic layout of the page -->
    <xsl:template match="/">
        <html>
            <head>
                <title>
                    <xsl:call-template name="translate">
                        <xsl:with-param name="id" select="'user_admin_title'" />
                    </xsl:call-template>
                </title>
                <link rel="icon" type="image/vnd.microsoft.icon">
                	<xsl:attribute name="href"><xsl:value-of select="concat($contextPath, '/swivel.ico')" /></xsl:attribute>
                </link>
                <link rel="shortcut icon" type="image/x-icon" >
                	<xsl:attribute name="href"><xsl:value-of select="concat($contextPath, '/swivel.ico')" /></xsl:attribute>
                </link>
                <link rel="stylesheet" type="text/css">
                    <xsl:attribute name="href">
                        <xsl:value-of select="concat($contextPath,'/interface/interface.css')" />
                    </xsl:attribute>
                </link>
                <script language="javascript" type="text/javascript">
                    function confirmDelete(event) {
                        var e = (window.event) ? window.event : event;
                        e.cancelBubble = true;
                        var confirmed = confirm("<xsl:call-template name="translate"><xsl:with-param name="id" select="'confirm_delete'" /></xsl:call-template>");
                        if (confirmed) {
                            alert("<xsl:call-template name="translate"><xsl:with-param name="id" select="'warn_xml_sync'"/></xsl:call-template>");
                        }
                        return confirmed;
                    }

                    var currentlySelected;

                    var contextPath = "<xsl:value-of select="$contextPath" />";

                    function updateAction(form) {
                        var loc = this.location.href;
                        var psn = loc.lastIndexOf('#');
                        if (psn > 0)
                            loc = loc.substring(0, psn);

                        if (currentlySelected)
                            loc += "#" + currentlySelected;

                        form.action = loc;
                    }

					function doSearch() {
						doSearchByPage(1);
					}
					
                    function doSearchByPage(pageNumber) {
                        var searchTerm = document.getElementById('search').value;
                        var filterValue = document.getElementById('filter').value;
                        var serverName = document.getElementById('repository_server').value;
                        var maxUsers = document.getElementById('max_users').value;
                        var usersPerPage = document.getElementById('users_per_page').value;
                        var filterType = document.getElementById('filterType').value;
                        var userView = document.getElementById('userView').value;
                        var userGroup = document.getElementById('userGroup').value;
                        var userSetField = document.getElementById('userSet');
                        var userSet = 'database';
                        if (userSetField) {
                        	userSet = userSetField.value;
                        }
                        var searchField = document.getElementById('searchField');
                        var searchFieldValue = "username";
                        if (searchField) {
                        	searchFieldValue = searchField.value;
                        }

                        var loc = contextPath + '/users';

                        loc += "?page=" + pageNumber;
                        if (userView) {
                            loc += '&amp;view=' + userView;
                        }
                        if (searchTerm) {
                            loc += '&amp;search=' + searchTerm;
                            pfx = "&amp;";
                        }
                        if (filterValue) {
                            loc += '&amp;filter=' + filterValue;
                            pfx = "&amp;";
                        }
                        if (userGroup) {
                            loc += '&amp;group=' + userGroup;
                            pfx = "&amp;";
                        }
                        loc += '&amp;repository_server=' + serverName;
                        loc += '&amp;user_set=' + userSet;
                        loc += '&amp;max_users=' + maxUsers;
                        loc += '&amp;users_per_page=' + usersPerPage;
                        loc += '&amp;filterType=' + filterType;
                        loc += '&amp;searchField=' + searchFieldValue;

                        window.location.href = loc;
                    }

                    function doReset() {
                        window.location.href = contextPath + "/users";
                    }

                    function add() {
                        var loc = contextPath + "/edit";
                        var serverName = document.getElementById('repository_server').value;
                        if (serverName) {
                            loc += "?repository_server=" + serverName;
                        }
                        window.location.href = loc;
                    }

                    function edit(username) {
                        window.location = contextPath + "/edit/" + username;
                    }
                    
                    function import_users() {
                    	var loc = contextPath + "/import";
                        var serverName = document.getElementById('repository_server').value;
                        if (serverName) {
                            loc += "?repository_server=" + serverName;
                        }
                        window.location.href = loc;
                    }

                    function pid(username) {
                        window.location = contextPath + "/pid/" + username;
                    }

                    function policy(username) {
                        window.location = contextPath + "/policy/" + username;
                    }

                    function resetPIN(username) {
                        window.location = contextPath + "/reset/" + username + "/pin";
                    }

                    function resetPassword(username) {
                        window.location = contextPath + "/reset/" + username + "/password";
                    }
                    
                    function viewStrings(username) {
                        window.location = contextPath + "/strings/" + username;
                    }

                    function resend(username) {
                        window.location = contextPath + "/resend/" + username;
                    }
                    
                    function history(username) {
                        window.location = contextPath + "/history/" + username;
                    }

                    function selectFirstUser() {
                        var loc = this.location.href;
                        var psn = loc.lastIndexOf('#');
                        if ((psn > 0) &amp;&amp; (loc.length > (psn + 1))) {
                            toggleButtons(loc.substring(psn + 1));
                        }
                    }

                    function toggleButtons(username) {
                        var usernameCell = document.getElementById('username-' + username);
                        var arrowImage = document.getElementById('arrow-' + username);
                        var buttonRow = document.getElementById('buttons-' + username);

                        if (buttonRow) {
                            if (buttonRow.className == 'buttons-hide') {
                                /* If a user is already selected de-select them */
                                if (currentlySelected)
                                    toggleButtons(currentlySelected);

                                currentlySelected = username;

                                /* Update classes */
                                if (usernameCell.className == 'username-first')
                                    usernameCell.className = 'username-first-selected';
                                else
                                    usernameCell.className = 'username-selected';

                                arrowImage.src = 'interface/up.gif';
                                buttonRow.className = 'buttons-show';

                                /* Special case for first row if (index == 1) usernameCell.style.borderTop = '0'; */

                                var element = usernameCell.nextSibling;
                                while (element) {
                                    if (element.className == 'membership')
                                        element.className = 'membership-selected';
                                    element = element.nextSibling;
                                }
                            } else {
                                /* Reset to nothing selected */
                                currentlySelected = '';

                                arrowImage.src = 'interface/down.gif';
                                buttonRow.className = 'buttons-hide';

                                if (usernameCell.className == 'username-first-selected')
                                    usernameCell.className = 'username-first';
                                else
                                    usernameCell.className = 'username';

                                var element = usernameCell.nextSibling;
                                while (element) {
                                    if (element.className == 'membership-selected')
                                        element.className = 'membership';
                                    element = element.nextSibling;
                                }
                            }
                        }
                    }

                    function confirmPurgeUser() {
                        return confirm('<xsl:call-template name="translate"><xsl:with-param name="id" select="'confirm_purge_user'"/></xsl:call-template>');
                    }

                    function confirmPurge() {
                        return confirm('<xsl:call-template name="translate"><xsl:with-param name="id" select="'confirm_purge'"/></xsl:call-template>');
                    }

                    function confirmUndelete() {
                        return confirm('<xsl:call-template name="translate"><xsl:with-param name="id" select="'confirm_undelete'"/></xsl:call-template>');
                    }
                </script>
                <script language="javascript" type="text/javascript">
                    <xsl:attribute name="src">
                        <xsl:value-of select="concat($contextPath,'/interface/menu.js')" />
                    </xsl:attribute>
                </script>
            </head>
            <body onload="selectFirstUser();">
                <table cellpadding="0" cellspacing="0" border="0" width="100%">
                    <xsl:for-each select="document($interfaceFile)/int:interface">
                        <xsl:call-template name="banner" >
                          <xsl:with-param name="servername" select="$servername"/>
                        </xsl:call-template>
                    </xsl:for-each>
                    <tr>
                        <!-- Create the menu -->
                        <xsl:for-each select="document($configFile)/cfg:config">
                            <xsl:call-template name="menu">
                                <xsl:with-param name="admin" select="$admin" />
                                <xsl:with-param name="helpDesk" select="$helpDesk" />
                                <xsl:with-param name="helpdeskView" select="$helpdeskView" />
                            </xsl:call-template>
                        </xsl:for-each>
                        <td id="content" colspan="2" valign="top">
                            <div id="content-wrap">
                                <h1 style="margin-bottom: 10px">
                                    <xsl:call-template name="translate">
                                        <xsl:with-param name="id" select="'user_admin_title'" />
                                    </xsl:call-template>
                                    <xsl:text disable-output-escaping="yes">&amp;nbsp;&amp;nbsp;</xsl:text>
                                    <a target="help">
                                        <xsl:attribute name="href">
                                            <xsl:value-of select="concat($contextPath,'/')" />
                                            <xsl:for-each select="document($helpFile)/hlp:help">
                                                <xsl:value-of select="hlp:page[@name='users']" />
                                            </xsl:for-each>
                                        </xsl:attribute>
                                        <img border="0">
                                            <xsl:attribute name="src">
                                                <xsl:value-of select="concat($contextPath,'/interface/help.jpg')" />
                                            </xsl:attribute>
                                            <xsl:attribute name="alt">
                                                <xsl:call-template name="translate">
                                                    <xsl:with-param name="id" select="'help'" />
                                                </xsl:call-template>
                                            </xsl:attribute>
                                        </img>
                                    </a>
                                </h1>
                                <xsl:if test="$pages &gt; 1"><xsl:call-template name="navigation" /></xsl:if>
              					<xsl:call-template name="errorMsg" />
                                <form method="post" onsubmit="updateAction(this)">
                                    <table width="90%">
                                        <tr>
                                            <td>
                                                <xsl:call-template name="controls" />
                                                <xsl:apply-templates select="usr:users" />
                                            </td>
                                        </tr>
                                    </table>
                                </form>
                                <br />
                                <xsl:if test="(count(usr:users/usr:user) &gt; 10) and ($pages &gt; 1)">
                                    <xsl:call-template name="navigation" />
                                </xsl:if>
                            </div>
                        </td>
                    </tr>
                </table>
            </body>
        </html>
    </xsl:template>

    <!-- Outputs navigation -->
    <xsl:template name="navigation">
        <table width="90%">
            <tr>
            	<td width="50%"><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></td>
                <td width="10%" align="left">
                    <xsl:if test="$page &gt; 1">
                        <a href="#" onclick="doSearchByPage(1);">
                            <xsl:call-template name="translate">
                                <xsl:with-param name="id" select="'previous'" />
                            </xsl:call-template>
                        </a>
                    </xsl:if>
                </td>
                <td width="30%" align="center">
                	<xsl:call-template name="translate"><xsl:with-param name="id" select="'page'" /></xsl:call-template> 
                    <xsl:if test="$page &gt; 5 and $pages &gt; 9">
                        <a href="#" onclick="doSearchByPage(1)">
                            <xsl:text>1</xsl:text>
                        </a>
                        <xsl:text disable-output-escaping="yes">&amp;nbsp;&amp;#133;</xsl:text>
                    </xsl:if>
                    <xsl:call-template name="page-link">
                        <xsl:with-param name="num">
                            <xsl:choose>
                                <xsl:when test="$page &lt; 6">1</xsl:when>
                                <xsl:when test="($page + 4) &gt; $pages">
                                    <xsl:value-of select="$pages - 8" />
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="$page - 4" />
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:with-param>
                        <xsl:with-param name="count" select="1" />
                    </xsl:call-template>
                    <xsl:if test="($page + 4) &lt; $pages and $pages &gt; 9">
                        <xsl:text disable-output-escaping="yes">&amp;nbsp;&amp;#133;&amp;nbsp;</xsl:text>
                        <a href="#">
                        	<xsl:attribute name="onclick">
                                <xsl:value-of select="concat('doSearchByPage(',$pages,');')" />
                            </xsl:attribute>
                            <xsl:value-of select="$pages" />
                        </a>
                    </xsl:if>
                </td>
                <td width="10%" align="right">
                    <xsl:if test="$page &lt; $pages">
                        <a href="#">
                            <xsl:attribute name="onclick">
                                <xsl:value-of select="concat('doSearchByPage(',$page + 1,');')" />
                            </xsl:attribute>
                            <xsl:call-template name="translate">
                                <xsl:with-param name="id" select="'next'" />
                            </xsl:call-template>
                        </a>
                    </xsl:if>
                </td>
            </tr>
        </table>
    </xsl:template>

    <!-- Outputs a link to a page -->
    <xsl:template name="page-link">
        <xsl:param name="num" />
        <xsl:param name="count" />
        <xsl:choose>
            <xsl:when test="$num = $page">
                <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                <b>
                    <xsl:value-of select="$num" />
                </b>
            </xsl:when>
            <xsl:when test="$num &gt; 0">
                <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                <a href="#">
                    <xsl:attribute name="onclick">
                        <xsl:value-of select="concat('doSearchByPage(',$num,');')" />
                    </xsl:attribute>
                    <xsl:value-of select="$num" />
                </a>
            </xsl:when>
        </xsl:choose>
        <xsl:if test="($num &lt; $pages) and ($count &lt; 9)">
            <xsl:call-template name="page-link">
                <xsl:with-param name="num" select="$num+1" />
                <xsl:with-param name="count" select="$count+1" />
            </xsl:call-template>
        </xsl:if>
    </xsl:template>

    <!-- Outputs controls -->
    <xsl:template name="controls">
        <table width="100%" style="margin-bottom: 1em;">
            <tr>
                <td>
                    <xsl:call-template name="translate">
                        <xsl:with-param name="id" select="'users_max_selected'" />
                    </xsl:call-template>
                    <xsl:text disable-output-escaping="yes">:</xsl:text>
                </td>
                <td nowrap="nowrap">
                    <input type="text" id="max_users" name="max_users" size="10">
                        <xsl:attribute name="value">
                            <xsl:value-of select="$maxUsers" />
                        </xsl:attribute>
                    </input>
                &#xa0;(<xsl:value-of select="$userCount" />&#xa0;<xsl:call-template name="translate">
                        <xsl:with-param name="id" select="'user_count_title'"/>
                    </xsl:call-template>)</td>
            </tr>
            <tr>
                <td>
                    <xsl:call-template name="translate">
                        <xsl:with-param name="id" select="'users_per_page'" />
                    </xsl:call-template>
                    <xsl:text disable-output-escaping="yes">:</xsl:text>
                </td>
                <td>
                    <input id="users_per_page" name="users_per_page">
                        <xsl:attribute name="value">
                            <xsl:value-of select="$usersPerPage" />
                        </xsl:attribute>
                    </input>
                </td>
            </tr>
            <tr>
                <td>
                    <xsl:call-template name="translate">
                        <xsl:with-param name="id" select="'repositoryserver'" />
                    </xsl:call-template>
                    <xsl:text disable-output-escaping="yes">:</xsl:text>
                </td>
                <td>
                    <xsl:choose>
                        <xsl:when test="count(//usr:server)&gt;1">
                            <select id="repository_server" style="width:100%;" name="repository_server" onchange="doSearch();">
                                <xsl:for-each select="//usr:server">
                                    <option>
                                        <xsl:attribute name="value">
                                            <xsl:value-of select="@serverID" />
                                        </xsl:attribute>
                                        <xsl:if test="@selected='true'">
                                            <xsl:attribute name="selected">selected</xsl:attribute>
                                        </xsl:if>
                                        <xsl:choose>
                                            <xsl:when test="@serverID='*'">
                                                <xsl:call-template name="translate">
                                                    <xsl:with-param name="id" select="." />
                                                </xsl:call-template>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="." />
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </option>
                                </xsl:for-each>
                            </select>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:for-each select="//usr:server">
                                <input type="hidden" id="repository_server" name="repository_server">
                                    <xsl:attribute name="value">
                                        <xsl:value-of select="." />
                                    </xsl:attribute>
                                </input>
                                <xsl:value-of select="." />
                            </xsl:for-each>
                        </xsl:otherwise>
                    </xsl:choose>
                </td>
            </tr>
            <tr>
                <td>
                    <xsl:call-template name="translate">
                        <xsl:with-param name="id" select="'state'" />
                    </xsl:call-template>
                    <xsl:text disable-output-escaping="yes">:</xsl:text>
                </td>
                <td>
                    <select id="filter" style="width: 100%;" onchange="doSearch();">
                        <option value="">
                            <xsl:call-template name="translate">
                                <xsl:with-param name="id" select="'all'" />
                            </xsl:call-template>
                        </option>
                        <option value="active">
                            <xsl:if test="$filter='active'">
                                <xsl:attribute name="selected" />
                            </xsl:if>
                            <xsl:call-template name="translate">
                                <xsl:with-param name="id" select="'active'" />
                            </xsl:call-template>
                        </option>
                        <option value="inactive">
                            <xsl:if test="$filter='inactive'">
                                <xsl:attribute name="selected" />
                            </xsl:if>
                            <xsl:call-template name="translate">
                                <xsl:with-param name="id" select="'inactive'" />
                            </xsl:call-template>
                        </option>
                        <option value="locked">
                            <xsl:if test="$filter='locked'">
                                <xsl:attribute name="selected" />
                            </xsl:if>
                            <xsl:call-template name="translate">
                                <xsl:with-param name="id" select="'locked'" />
                            </xsl:call-template>
                        </option>
                        <option value="disabled">
                            <xsl:if test="$filter='disabled'">
                                <xsl:attribute name="selected" />
                            </xsl:if>
                            <xsl:call-template name="translate">
                                <xsl:with-param name="id" select="'disabled'" />
                            </xsl:call-template>
                        </option>
                        <option value="deleted">
                            <xsl:if test="$filter='deleted'">
                                <xsl:attribute name="selected" />
                            </xsl:if>
                            <xsl:call-template name="translate">
                                <xsl:with-param name="id" select="'deleted'" />
                            </xsl:call-template>
                        </option>
                    </select>
                </td>
            </tr>
            <tr>
                <td>
                	<xsl:choose>
                		<xsl:when test="$userSet='database'">
	                		<select name="searchField" id="searchField">
	                			<option value="username">
	                				<xsl:if test="$searchField='username'">
	                					<xsl:attribute name="selected">true</xsl:attribute>
	                				</xsl:if>
				                    <xsl:call-template name="translate">
				                        <xsl:with-param name="id" select="'username'" />
				                    </xsl:call-template>
			                    </option>
	                			<xsl:for-each select="/usr:users/usr:attributes/usr:name">
	                				<option>
		                				<xsl:if test="$searchField=.">
		                					<xsl:attribute name="selected">true</xsl:attribute>
		                				</xsl:if>
	                					<xsl:value-of select="."/>
	                				</option>
	                			</xsl:for-each>
	                		</select>
                		</xsl:when>
	                	<xsl:when test="$editable and $userSet='repository'">
	                		<select name="searchField" id="searchField">
	                			<option value="username">
				                    <xsl:if test="$searchField='username'">
				                    	<xsl:attribute name="selected">selected</xsl:attribute>
				                    </xsl:if>
				                    <xsl:call-template name="translate">
				                        <xsl:with-param name="id" select="'username'" />
				                    </xsl:call-template>
				                    <xsl:text disable-output-escaping="yes">:</xsl:text>
	                			</option>
	                			<option value="surname">
				                    <xsl:if test="$searchField='surname'">
				                    	<xsl:attribute name="selected">selected</xsl:attribute>
				                    </xsl:if>
				                    <xsl:call-template name="translate">
				                        <xsl:with-param name="id" select="'sn'" />
				                    </xsl:call-template>
				                    <xsl:text disable-output-escaping="yes">:</xsl:text>
	                			</option>
	                		</select>
	                	</xsl:when>
	                	<xsl:otherwise>
		                    <xsl:call-template name="translate">
		                        <xsl:with-param name="id" select="'username'" />
		                    </xsl:call-template>
		                    <xsl:text disable-output-escaping="yes">:</xsl:text>
	                    </xsl:otherwise>
                    </xsl:choose>
                </td>
                <td>
                    <select name="filterType" id="filterType">
                        <option value="contains">
                            <xsl:if test="$filterType!='starts'">
                                <xsl:attribute name="selected">selected</xsl:attribute>
                            </xsl:if>
                            <xsl:text>Contains</xsl:text>
                        </option>
                        <option value="starts">
                            <xsl:if test="$filterType='starts'">
                                <xsl:attribute name="selected">selected</xsl:attribute>
                            </xsl:if>
                            <xsl:text>Starts With</xsl:text>
                        </option>
                    </select>
                    <input type="text" id="search" size="16">
                        <xsl:attribute name="value">
                            <xsl:value-of select="$search" />
                        </xsl:attribute>
                    </input>
                </td>
            </tr>
            <tr>
                <td>
                    <xsl:call-template name="translate">
                        <xsl:with-param name="id" select="'user_admin_group'"/>
                    </xsl:call-template>:
                </td>
                <td>
                    <select id="userGroup" onchange="doSearch();">
                        <option value="">
                            <xsl:call-template name="translate">
                                <xsl:with-param name="id" select="'repository_groups_any_group'" />
                            </xsl:call-template>
                        </option>
                        <xsl:for-each select="/usr:users/usr:groups/usr:group">
                            <option>
                                <xsl:attribute name="value"><xsl:value-of select="."/></xsl:attribute>
                                <xsl:if test="$userGroup=text()">
                                    <xsl:attribute name="selected">true</xsl:attribute>
                                </xsl:if>
                                <xsl:value-of select="."/>
                            </option>
                        </xsl:for-each>
                    </select>
                </td>
            </tr>
            <tr>
                <td>
                    <xsl:call-template name="translate">
                        <xsl:with-param name="id" select="'user_admin_view'" />
                    </xsl:call-template>
                </td>
                <td>
                    <select id="userView" onchange="doSearch();">
                        <option value="rights">
                            <xsl:if test="$view='rights'">
                                <xsl:attribute name="selected">true</xsl:attribute>
                            </xsl:if>
                            <xsl:call-template name="translate">
                                <xsl:with-param name="id" select="'user_admin_view_rights'" />
                            </xsl:call-template>
                        </option>
                        <option value="groups">
                            <xsl:if test="$view='groups'">
                                <xsl:attribute name="selected">true</xsl:attribute>
                            </xsl:if>
                            <xsl:call-template name="translate">
                                <xsl:with-param name="id" select="'user_admin_view_groups'" />
                            </xsl:call-template>
                        </option>
                        <option value="transport">
                            <xsl:if test="$view='transport'">
                                <xsl:attribute name="selected">true</xsl:attribute>
                            </xsl:if>
                            <xsl:call-template name="translate">
                                <xsl:with-param name="id" select="'user_admin_view_transport'" />
                            </xsl:call-template>
                        </option>
                        <option value="attributes">
                        	<xsl:if test="$view='attributes'">
                        		<xsl:attribute name="selected">true</xsl:attribute>
                        	</xsl:if>
                        	<xsl:call-template name="translate">
                        		<xsl:with-param name="id" select="'user_admin_view_attributes'" />
                        	</xsl:call-template>
                        </option>
                    </select>
                </td>
            </tr>
            <xsl:if test="$editable">
            <tr>
            	<td>
            		<xsl:call-template name="translate">
            			<xsl:with-param name="id" select="'user_admin_user_set'" />
            		</xsl:call-template>
                    <xsl:text disable-output-escaping="yes">:</xsl:text>
            	</td>
            	<td>
            		<select id="userSet" onchange="doSearch();">
            			<option value="repository">
            				<xsl:if test="$userSet='repository'">
            					<xsl:attribute name="selected">true</xsl:attribute>
            				</xsl:if>
            				<xsl:call-template name="translate">
            					<xsl:with-param name="id" select="'user_admin_userset_repository'"/>
            				</xsl:call-template>
            			</option>
            			<option value="database">
            				<xsl:if test="$userSet='database'">
            					<xsl:attribute name="selected">true</xsl:attribute>
            				</xsl:if>
            				<xsl:call-template name="translate">
            					<xsl:with-param name="id" select="'user_admin_userset_database'"/>
            				</xsl:call-template>
            			</option>
            		</select>
            	</td>
            </tr>
            </xsl:if>
            <tr>
                <td colspan="2">&#xa0;</td>
                <td nowrap="nowrap">
                    <input type="submit" onclick="doSearch(); return false;">
                        <xsl:attribute name="value">
                            <xsl:call-template name="translate">
                                <xsl:with-param name="id" select="'search'" />
                            </xsl:call-template>
                        </xsl:attribute>
                    </input>
                    <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                    <input type="button" onclick="doReset();">
                        <xsl:attribute name="value">
                            <xsl:call-template name="translate">
                                <xsl:with-param name="id" select="'reset'" />
                            </xsl:call-template>
                        </xsl:attribute>
                    </input>
                </td>
                <td nowrap="nowrap">
                	<xsl:if test="$canPurge='true'">
                    <input type="submit" name="purge" onclick="return confirmPurge();">
                        <xsl:attribute name="value">
                            <xsl:call-template name="translate">
                                <xsl:with-param name="id" select="'purge_deleted'" />
                            </xsl:call-template>
                        </xsl:attribute>
                        <xsl:if test="$repository='*'">
                            <xsl:attribute name="disabled">disabled</xsl:attribute>
                        </xsl:if>
                    </input>
                    <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                    <input type="submit" name="undelete" onclick="return confirmUndelete();">
                        <xsl:attribute name="value">
                            <xsl:call-template name="translate">
                                <xsl:with-param name="id" select="'undelete'" />
                            </xsl:call-template>
                        </xsl:attribute>
                        <xsl:if test="$repository='*'">
                            <xsl:attribute name="disabled">disabled</xsl:attribute>
                        </xsl:if>
                    </input>
                    </xsl:if>
                </td>
                <td width="100%" align="right" nowrap="nowrap">
                    <xsl:if test="/usr:users[@editable] and $xmlHelpDesk='true'">
                        <input type="button" onclick="add();">
                            <xsl:attribute name="value">
                                <xsl:call-template name="translate">
                                    <xsl:with-param name="id" select="'add_user'" />
                                </xsl:call-template>
                            </xsl:attribute>
                        </input>
                        <xsl:if test="$admin='true'">
                    	<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                        <input type="button" onclick="import_users();">
                            <xsl:attribute name="value">
                                <xsl:call-template name="translate">
                                    <xsl:with-param name="id" select="'import_users'" />
                                </xsl:call-template>
                            </xsl:attribute>
                        </input>
                        </xsl:if>
                    </xsl:if>
                    <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                    <xsl:if test="/usr:users[@master]">
                        <input type="submit" name="synchronise">
                            <xsl:attribute name="value">
                                <xsl:call-template name="translate">
                                    <xsl:with-param name="id" select="'synchronise'" />
                                </xsl:call-template>
                            </xsl:attribute>
                        </input>
                    </xsl:if>
                     <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                    <xsl:if test="/usr:users[@master]">
                        <input type="submit" name="syncusercount">
                            <xsl:attribute name="value">
                                <xsl:call-template name="translate">
                                    <xsl:with-param name="id" select="'syncusercount'" />
                                </xsl:call-template>
                            </xsl:attribute>
                        </input>
                    </xsl:if>
                </td>
            </tr>
        </table>
    </xsl:template>

    <!-- Outputs the table of users -->
    <xsl:template match="usr:users">
        <table id="users" cellpadding="0" cellspacing="0" border="0" align="center">
            <xsl:choose>
                <xsl:when test="$view='transport'">
                    <xsl:call-template name="user-transport-header"/>
                </xsl:when>
                <xsl:when test="$view='groups'">
                    <xsl:call-template name="user-groups-header" />
                </xsl:when>
                <xsl:when test="$view='attributes'">
                	<xsl:call-template name="user-attributes-header" />
                </xsl:when>
                <xsl:otherwise>
                    <xsl:call-template name="user-rights-header" />
                </xsl:otherwise>
            </xsl:choose>
            <xsl:choose>
                <xsl:when test="$view='transport'">
                    <xsl:apply-templates select="usr:user" mode="transport">
                        <xsl:sort select="usr:username" />
                    </xsl:apply-templates>
                </xsl:when>
                <xsl:when test="$view='groups'">
                    <xsl:apply-templates select="usr:user" mode="groups">
                        <xsl:sort select="usr:username" />
                    </xsl:apply-templates>
                </xsl:when>
                <xsl:when test="$view='attributes'">
                	<xsl:apply-templates select="usr:user" mode="attributes">
                		<xsl:sort select="usr:username" />
                	</xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:apply-templates select="usr:user" mode="rights">
                        <xsl:sort select="usr:username" />
                    </xsl:apply-templates>
                </xsl:otherwise>
            </xsl:choose>
        </table>
    </xsl:template>

    <xsl:template name="user-rights-header">
        <xsl:if test="usr:user">
            <colgroup>
                <col />
                <col width="8%" />
                <col width="8%" />
                <col width="8%" />
                <col width="8%" />
                <col width="8%" />
                <col width="8%" />
                <col width="8%" />                
                <col width="8%" />                
            </colgroup>
        </xsl:if>
        <thead>
            <tr>
                <td style="border-left: 1px solid black">
                    <xsl:call-template name="translate">
                        <xsl:with-param name="id" select="'username'" />
                    </xsl:call-template>
                </td>
                <td>
                    <xsl:call-template name="translate">
                        <xsl:with-param name="id" select="'admin'" />
                    </xsl:call-template>
                </td>
                <td>
                    <xsl:call-template name="translate">
                        <xsl:with-param name="id" select="'helpdesk'" />
                    </xsl:call-template>
                </td>
                <td>
                    <xsl:call-template name="translate">
                        <xsl:with-param name="id" select="'single'" />
                    </xsl:call-template>
                </td>
                <td>
                    <xsl:call-template name="translate">
                        <xsl:with-param name="id" select="'dual'" />
                    </xsl:call-template>
                </td>
                <td>
                    <xsl:call-template name="translate">
                        <xsl:with-param name="id" select="'telephony'" />
                    </xsl:call-template>
                </td>
                <td>
                    <xsl:call-template name="translate">
                        <xsl:with-param name="id" select="'token'" />
                    </xsl:call-template>
                </td>
                <td>
                    <xsl:call-template name="translate">
                        <xsl:with-param name="id" select="'pinless'" />
                    </xsl:call-template>
                </td>
                <td>
                    <xsl:call-template name="translate">
                        <xsl:with-param name="id" select="'oath'" />
                    </xsl:call-template>
                </td>
            </tr>
        </thead>
    </xsl:template>

    <xsl:template name="user-transport-header">
        <xsl:if test="usr:user">
            <colgroup>
                <col />
                <col width="10%" />
                <col width="25%" />
                <col width="10%" />
                <col width="25%" />
            </colgroup>
        </xsl:if>
        <thead>
            <tr>
                <td style="border-left: 1px solid black" rowspan="2">
                    <xsl:call-template name="translate">
                        <xsl:with-param name="id" select="'username'" />
                    </xsl:call-template>
                </td>
                <td colspan="2" style="border-bottom: 0">
                    <xsl:call-template name="translate">
                        <xsl:with-param name="id" select="'user_transport_security'" />
                    </xsl:call-template>
                </td>
                <td colspan="2" style="border-bottom: 0">
                    <xsl:call-template name="translate">
                        <xsl:with-param name="id" select="'user_transport_alerts'" />
                    </xsl:call-template>
                </td>
            </tr>
            <tr>
                <td style="border-top: 0">
                    <xsl:call-template name="translate">
                        <xsl:with-param name="id" select="'user_transport_transport'" />
                    </xsl:call-template>
                </td>
                <td style="border-top: 0">
                    <xsl:call-template name="translate">
                        <xsl:with-param name="id" select="'user_transport_destination'" />
                    </xsl:call-template>
                </td>
                <td style="border-top: 0">
                    <xsl:call-template name="translate">
                        <xsl:with-param name="id" select="'user_transport_transport'" />
                    </xsl:call-template>
                </td>
                <td style="border-top: 0">
                    <xsl:call-template name="translate">
                        <xsl:with-param name="id" select="'user_transport_destination'" />
                    </xsl:call-template>
                </td>
            </tr>
        </thead>
    </xsl:template>

    <xsl:template name="user-groups-header">
        <thead>
            <tr>
                <td style="border-left: 1px solid black">
                    <xsl:call-template name="translate">
                        <xsl:with-param name="id" select="'username'" />
                    </xsl:call-template>
                </td>
                <xsl:for-each select="usr:groups/usr:group">
                    <td>
                        <xsl:value-of select="text()" />
                    </td>
                </xsl:for-each>
            </tr>
        </thead>
    </xsl:template>

    <xsl:template name="user-attributes-header">
        <thead>
            <tr>
                <td style="border-left: 1px solid black">
                    <xsl:call-template name="translate">
                        <xsl:with-param name="id" select="'username'" />
                    </xsl:call-template>
                </td>
                <xsl:for-each select="usr:attributes/usr:name">
                    <td>
                        <xsl:value-of select="text()" />
                    </td>
                </xsl:for-each>
            </tr>
        </thead>
    </xsl:template>
    
    <xsl:template match="usr:user" mode="username">
        <td>
            <xsl:attribute name="id">
                <xsl:value-of select="concat('username-',usr:encode-repos-name)" />
            </xsl:attribute>
            <xsl:attribute name="class">
                <xsl:choose>
                    <xsl:when test="position()=1">username-first</xsl:when>
                    <xsl:otherwise>username</xsl:otherwise>
                </xsl:choose>
            </xsl:attribute>
            <xsl:attribute name="onclick">
                <xsl:value-of select="concat('toggleButtons(&quot;',usr:encode-repos-name,'&quot;);')" />
            </xsl:attribute>
            <img src="interface/down.gif">
                <xsl:attribute name="id">
                    <xsl:value-of select="concat('arrow-',usr:encode-repos-name)" />
                </xsl:attribute>
            </img>
            <span>
                <xsl:attribute name="style">
                    <xsl:if test="usr:locked">font-weight: bold;</xsl:if>
                    <xsl:if test="usr:disabled">font-style: italic;</xsl:if>
                    <xsl:if test="usr:deleted">text-decoration: line-through;</xsl:if>
                    <xsl:if test="usr:inactive">text-decoration: underline;</xsl:if>
                </xsl:attribute>
                <xsl:value-of select="usr:username" />
            </span>
        </td>
    </xsl:template>

    <!-- Outputs a user as a row in the users table -->
    <xsl:template match="usr:user" mode="transport">
        <tr>
            <xsl:attribute name="class">
                <xsl:choose>
                    <xsl:when test="position()=last()">
                        <xsl:choose>
                            <xsl:when test="(position() mod 2)=1">oddlast</xsl:when>
                            <xsl:otherwise>evenlast</xsl:otherwise>
                        </xsl:choose>
                    </xsl:when>
                    <xsl:when test="(position() mod 2)=1">odd</xsl:when>
                    <xsl:otherwise>even</xsl:otherwise>
                </xsl:choose>
            </xsl:attribute>
            <xsl:apply-templates select="." mode="username" />
            <td><xsl:choose>
                <xsl:when test="usr:transport/text()">
                    <xsl:value-of select="usr:transport" />
                </xsl:when>
                <xsl:otherwise><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></xsl:otherwise>
            </xsl:choose></td>
            <td><xsl:choose>
                <xsl:when test="usr:transport-destination/text()">
                   <xsl:value-of select="usr:transport-destination" />
                </xsl:when>
                <xsl:otherwise><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></xsl:otherwise>
            </xsl:choose></td>
            <td><xsl:choose>
                <xsl:when test="usr:alert-transport/text()">
                    <xsl:value-of select="usr:alert-transport" />
                </xsl:when>
                <xsl:otherwise><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></xsl:otherwise>
            </xsl:choose></td>
            <td><xsl:choose>
                <xsl:when test="usr:alert-transport-destination/text()">
                    <xsl:value-of select="usr:alert-transport-destination" />
                </xsl:when>
                <xsl:otherwise><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></xsl:otherwise>
            </xsl:choose></td>
        </tr>
        <xsl:call-template name="user-button-row">
            <xsl:with-param name="colCount" select="'5'" />
        </xsl:call-template>
    </xsl:template>

    <!-- Outputs a user as a row in the users table -->
    <xsl:template match="usr:user" mode="groups">
        <tr>
            <xsl:attribute name="class">
                <xsl:choose>
                    <xsl:when test="position()=last()">
                        <xsl:choose>
                            <xsl:when test="(position() mod 2)=1">oddlast</xsl:when>
                            <xsl:otherwise>evenlast</xsl:otherwise>
                        </xsl:choose>
                    </xsl:when>
                    <xsl:when test="(position() mod 2)=1">odd</xsl:when>
                    <xsl:otherwise>even</xsl:otherwise>
                </xsl:choose>
            </xsl:attribute>
            <xsl:apply-templates select="." mode="username" />
            <xsl:apply-templates select="usr:groups/usr:group" />
        </tr>
        <xsl:call-template name="user-button-row">
            <xsl:with-param name="colCount" select="count(usr:groups/usr:group) + 1" />
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="usr:group">
        <td class="membership">
            <xsl:choose>
                <xsl:when test="@member">
                    <img src="interface/tick.gif" />
                </xsl:when>
                <xsl:otherwise>
                    <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                </xsl:otherwise>
            </xsl:choose>
        </td>
    </xsl:template>

    <!-- Outputs a user as a row in the users table -->
    <xsl:template match="usr:user" mode="attributes">
        <tr>
            <xsl:attribute name="class">
                <xsl:choose>
                    <xsl:when test="position()=last()">
                        <xsl:choose>
                            <xsl:when test="(position() mod 2)=1">oddlast</xsl:when>
                            <xsl:otherwise>evenlast</xsl:otherwise>
                        </xsl:choose>
                    </xsl:when>
                    <xsl:when test="(position() mod 2)=1">odd</xsl:when>
                    <xsl:otherwise>even</xsl:otherwise>
                </xsl:choose>
            </xsl:attribute>
            <xsl:apply-templates select="." mode="username" />
            <xsl:apply-templates select="usr:attributes/usr:attribute">
                <xsl:with-param name="user" select="." />
            </xsl:apply-templates>
        </tr>
        <xsl:call-template name="user-button-row">
            <xsl:with-param name="colCount" select="count(usr:attributes/usr:attribute) + 1" />
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="usr:attribute">
        <td><xsl:value-of select="text()" /></td>
    </xsl:template>

    <!-- Outputs a user as a row in the users table -->
    <xsl:template match="usr:user" mode="rights">
        <tr>
            <xsl:attribute name="class">
                <xsl:choose>
                    <xsl:when test="position()=last()">
                        <xsl:choose>
                            <xsl:when test="(position() mod 2)=1">oddlast</xsl:when>
                            <xsl:otherwise>evenlast</xsl:otherwise>
                        </xsl:choose>
                    </xsl:when>
                    <xsl:when test="(position() mod 2)=1">odd</xsl:when>
                    <xsl:otherwise>even</xsl:otherwise>
                </xsl:choose>
            </xsl:attribute>
            <xsl:apply-templates select="." mode="username" />
            <td class="membership">
                <xsl:choose>
                    <xsl:when test="usr:rights/usr:admin">
                        <img src="interface/tick.gif" />
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
            </td>
            <td class="membership">
                <xsl:choose>
                    <xsl:when test="usr:rights/usr:helpdesk">
                        <img src="interface/tick.gif" />
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
            </td>
            <td class="membership">
                <xsl:choose>
                    <xsl:when test="usr:rights/usr:single">
                        <img src="interface/tick.gif" />
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
            </td>
            <td class="membership">
                <xsl:choose>
                    <xsl:when test="usr:rights/usr:dual">
                        <img src="interface/tick.gif" />
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
            </td>
            <td class="membership">
                <xsl:choose>
                    <xsl:when test="usr:rights/usr:telephony">
                        <img src="interface/tick.gif" />
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
            </td>            
            <td class="membership">
                <xsl:choose>
                    <xsl:when test="usr:rights/usr:token">
                        <img src="interface/tick.gif" />
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
            </td>
            <td class="membership">
                <xsl:choose>
                    <xsl:when test="usr:rights/usr:pinless">
                        <img src="interface/tick.gif" />
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
            </td>
            <td class="membership">
                <xsl:choose>
                    <xsl:when test="usr:rights/usr:oath">
                        <img src="interface/tick.gif" />
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
            </td>
        </tr>
        <!--  make sure that if you add a column above you increment the number below -->
        <xsl:call-template name="user-button-row">
            <xsl:with-param name="colCount" select="'9'" />
        </xsl:call-template>
    </xsl:template>

    <xsl:template name="user-button-row">
        <xsl:param name="colCount" />
        <tr>
            <td class="buttons-hide">
                <xsl:attribute name="colspan"><xsl:value-of select="$colCount" /></xsl:attribute>
                <xsl:attribute name="id">
                    <xsl:value-of select="concat('buttons-',usr:encode-repos-name)" />
                </xsl:attribute>
                <input type="button">
                    <xsl:attribute name="value">
                        <xsl:call-template name="translate">
                            <xsl:with-param name="id" select="'edit'" />
                        </xsl:call-template>
                    </xsl:attribute>
                    <xsl:attribute name="onclick">
                        <xsl:value-of select="concat('edit(&quot;',usr:encode-repos-name,'&quot;);')" />
                    </xsl:attribute>
                    <xsl:if test="not(/usr:users[@editable]) or $xmlHelpDesk='false' or @editable='false' or @editable='db'">
                        <xsl:attribute name="disabled">true</xsl:attribute>
                    </xsl:if>
                </input>
                <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                <xsl:if test="//usr:pid">
                    <input type="button">
                        <xsl:attribute name="value">
                            <xsl:call-template name="translate">
                                <xsl:with-param name="id" select="'pid'" />
                            </xsl:call-template>
                        </xsl:attribute>
                        <xsl:attribute name="onclick">
                            <xsl:value-of select="concat('pid(&quot;',usr:encode-name,'&quot;);')" />
                        </xsl:attribute>
                        <xsl:if test="not(usr:pid)">
                            <xsl:attribute name="disabled">true</xsl:attribute>
                        </xsl:if>
                    </input>
                    <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                </xsl:if>
                <input type="button">
                    <xsl:attribute name="value">
                        <xsl:call-template name="translate">
                            <xsl:with-param name="id" select="'policy'" />
                        </xsl:call-template>
                    </xsl:attribute>
                    <xsl:attribute name="onclick">
                        <xsl:value-of select="concat('policy(&quot;',usr:encode-name,'&quot;);')" />
                    </xsl:attribute>
                    <xsl:if test="usr:deleted or not(usr:swivel) or ($admin='false' and (usr:rights/usr:admin))">
                        <xsl:attribute name="disabled">true</xsl:attribute>
                    </xsl:if>
                </input>
                <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                <input type="button">
                    <xsl:attribute name="value">
                        <xsl:call-template name="translate">
                            <xsl:with-param name="id" select="'reset_pin'" />
                        </xsl:call-template>
                    </xsl:attribute>
                    <xsl:attribute name="onclick">
                        <xsl:value-of select="concat('resetPIN(&quot;',usr:encode-name,'&quot;);')" />
                    </xsl:attribute>
                    <xsl:if test="usr:deleted or not(usr:swivel) or (@needsPin='false') or ($admin='false' and (usr:rights/usr:admin or $noReset)) or @editable='false'">
                        <xsl:attribute name="disabled">true</xsl:attribute>
                    </xsl:if>
                </input>
                <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                <input type="button">
                    <xsl:attribute name="value">
                        <xsl:call-template name="translate">
                            <xsl:with-param name="id" select="'reset_password'" />
                        </xsl:call-template>
                    </xsl:attribute>
                    <xsl:attribute name="onclick">
                        <xsl:value-of select="concat('resetPassword(&quot;',usr:encode-name,'&quot;);')" />
                    </xsl:attribute>
                    <xsl:if test="usr:deleted or not(usr:swivel) or @editable='false' or $noPassword or ($admin='false' and ($noReset or usr:rights/usr:admin))">
                        <xsl:attribute name="disabled">true</xsl:attribute>
                    </xsl:if>
                </input>
                <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                <xsl:if test="usr:rights/usr:dual or usr:rights/usr:single">
                <input type="button">
                    <xsl:attribute name="value">
                        <xsl:call-template name="translate">
                            <xsl:with-param name="id" select="'view_strings'" />
                        </xsl:call-template>
                    </xsl:attribute>
                    <xsl:if test="usr:deleted or usr:locked or usr:disabled">
                    	<xsl:attribute name="disabled">true</xsl:attribute>
                    </xsl:if>
                    <xsl:attribute name="onclick">
                        <xsl:value-of select="concat('viewStrings(&quot;',usr:encode-name,'&quot;);')" />
                    </xsl:attribute>
                </input>
                </xsl:if>
                <xsl:if test="usr:rights/usr:dual">
                    <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                    <input type="submit">
                        <xsl:attribute name="value">
                            <xsl:call-template name="translate">
                                <xsl:with-param name="id" select="'send_strings'"/>
                            </xsl:call-template>
                        </xsl:attribute>
                        <xsl:attribute name="name">
                            <xsl:value-of select="concat(usr:encode-name, '.strings')"/>
                        </xsl:attribute>
	                    <xsl:if test="usr:deleted or usr:locked or usr:disabled">
	                    	<xsl:attribute name="disabled">true</xsl:attribute>
	                    </xsl:if>
                    </input>
                </xsl:if>
                <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                <input type="submit">
                    <xsl:attribute name="value">
                        <xsl:call-template name="translate">
                            <xsl:with-param name="id" select="'resend'" />
                        </xsl:call-template>
                    </xsl:attribute>
                    <xsl:attribute name="name">
                        <xsl:value-of select="concat(usr:encode-name,'.resend')" />
                    </xsl:attribute>
                    <xsl:if test="usr:deleted or not(usr:swivel) or @needsPin='false'">
                        <xsl:attribute name="disabled">true</xsl:attribute>
                    </xsl:if>
                </input>
                <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
				<xsl:if test="usr:rights/usr:token">
                <input type="submit">
                    <xsl:attribute name="value">
                        <xsl:call-template name="translate">
                            <xsl:with-param name="id" select="'quick_provision'" />
                        </xsl:call-template>
                    </xsl:attribute>
                    <xsl:attribute name="name">
                        <xsl:value-of select="concat(usr:username,'.quickprovision')" />
                    </xsl:attribute>
         			<xsl:if test="usr:deleted">                    
                        <xsl:attribute name="disabled">true</xsl:attribute>
                    </xsl:if>
                </input>
                 <input type="submit">
                    <xsl:attribute name="value">
                        <xsl:call-template name="translate">
                            <xsl:with-param name="id" select="'manual_provision'" />
                        </xsl:call-template>
                    </xsl:attribute>
                    <xsl:attribute name="name">
                        <xsl:value-of select="concat(usr:username,'.manualprovision')" />
                    </xsl:attribute>
         			<xsl:if test="usr:deleted">                    
                        <xsl:attribute name="disabled">true</xsl:attribute>
                    </xsl:if>
                </input>
                </xsl:if>
                <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
 
                <input type="submit">
                    <xsl:choose>
                        <xsl:when test="usr:locked or usr:inactive">
                            <xsl:attribute name="value">
                                <xsl:call-template name="translate">
                                    <xsl:with-param name="id" select="'unlock'" />
                                </xsl:call-template>
                            </xsl:attribute>
                            <xsl:attribute name="name">
                                <xsl:value-of select="concat(usr:encode-name,'.unlock')" />
                            </xsl:attribute>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:attribute name="value">
                                <xsl:call-template name="translate">
                                    <xsl:with-param name="id" select="'lock'" />
                                </xsl:call-template>
                            </xsl:attribute>
                            <xsl:attribute name="name">
                                <xsl:value-of select="concat(usr:encode-name,'.lock')" />
                            </xsl:attribute>
                            <xsl:if test="usr:deleted or not(usr:swivel) or ($admin='false' and usr:rights/usr:admin)">
                                <xsl:attribute name="disabled">true</xsl:attribute>
                            </xsl:if>
                        </xsl:otherwise>
                    </xsl:choose>
                </input>
                <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                <xsl:choose>
                <xsl:when test="usr:deleted">
                <input type="submit">
                    <xsl:attribute name="value">
                        <xsl:call-template name="translate">
                            <xsl:with-param name="id" select="'undelete'" />
                        </xsl:call-template>
                    </xsl:attribute>
                    <xsl:attribute name="name">
                        <xsl:value-of select="concat(usr:encode-name,'.undelete')" />
                    </xsl:attribute>
                    <xsl:if test="$xmlHelpDesk='false'">
                        <xsl:attribute name="disabled">true</xsl:attribute>
                    </xsl:if>
                </input>
                <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                <input type="submit" onclick="return confirmPurgeUser()">
                    <xsl:attribute name="value">
                        <xsl:call-template name="translate">
                            <xsl:with-param name="id" select="'purge_deleted'" />
                        </xsl:call-template>
                    </xsl:attribute>
                    <xsl:attribute name="name">
                        <xsl:value-of select="concat(usr:encode-name,'.purge')" />
                    </xsl:attribute>
                    <xsl:if test="$xmlHelpDesk='false'">
                        <xsl:attribute name="disabled">true</xsl:attribute>
                    </xsl:if>
                </input>
                </xsl:when>
                <xsl:otherwise>
                <input type="submit" onclick="return confirmDelete(event);">
                    <xsl:attribute name="value">
                        <xsl:call-template name="translate">
                            <xsl:with-param name="id" select="'remove'" />
                        </xsl:call-template>
                    </xsl:attribute>
                    <xsl:attribute name="name">
                        <xsl:value-of select="concat(usr:encode-name,'.delete')" />
                    </xsl:attribute>
                    <xsl:if test="not(/usr:users[@editable]) or $xmlHelpDesk='false' or @editable='false' or @editable='db'">
                        <xsl:attribute name="disabled">true</xsl:attribute>
                    </xsl:if>
                </input>
                </xsl:otherwise>
                </xsl:choose>
                <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                <input type="button">
                    <xsl:attribute name="value">
                        <xsl:call-template name="translate"><xsl:with-param name="id" select="'history'"/></xsl:call-template>
                    </xsl:attribute>
                    <xsl:attribute name="onclick">
                        <xsl:value-of select="concat('history(&quot;',usr:encode-name,'&quot;);')" />
                    </xsl:attribute>
                    <xsl:if test="not(usr:swivel)">
                    	<xsl:attribute name="disabled">true</xsl:attribute>
                    </xsl:if>
                </input>
            </td>
        </tr>
    </xsl:template>

    <!-- Display any error message -->
    <xsl:template name="errorMsg">
    <xsl:if test="$errorString and $errorString!=''">
      <h4 class="error">
        <xsl:value-of select="$errorString" disable-output-escaping="yes"/>
            </h4>
        </xsl:if>
    </xsl:template>
    
</xsl:stylesheet>
